@@ -1,6 +1,6 @@
 {-# LANGUAGE RecordWildCards #-}
 
--- | Immutable Compresed Sparse Row. It is re-exported from the @AtCoder.Extra.Graph@ module with
+-- | Immutable Compressed Sparse Row. It is re-exported from the @AtCoder.Extra.Graph@ module with
 -- additional functionalities.
 --
 -- ==== __Example__
@@ -43,7 +43,9 @@ module AtCoder.Internal.Csr
     -- * Accessors
     adj,
     adjW,
+    adj1,
     eAdj,
+    eAdjW,
   )
 where
 
@@ -55,7 +57,7 @@ import Data.Vector.Unboxed qualified as VU
 import Data.Vector.Unboxed.Mutable qualified as VUM
 import GHC.Stack (HasCallStack)
 
--- | Comperssed Sparse Row representation of a graph.
+-- | Compressed Sparse Row representation of a graph.
 --
 -- @since 1.0.0.0
 data Csr w = Csr
@@ -67,7 +69,7 @@ data Csr w = Csr
     --
     -- @since 1.1.0.0
     mCsr :: {-# UNPACK #-} !Int,
-    -- | Starting indices.
+    -- | Maps vertices into the starting indices for `adjCsr` and `wCsr`.
     --
     -- @since 1.1.0.0
     startCsr :: !(VU.Vector Int),
@@ -90,7 +92,7 @@ data Csr w = Csr
 -- | \(O(n + m)\) Creates a `Csr`.
 --
 -- @since 1.0.0.0
-{-# INLINE build #-}
+{-# INLINEABLE build #-}
 build :: (HasCallStack, VU.Unbox w) => Int -> VU.Vector (Int, Int, w) -> Csr w
 build nCsr edges = runST $ do
   let mCsr = VU.length edges
@@ -157,7 +159,17 @@ adjW Csr {..} i =
       ir = startCsr VG.! (i + 1)
    in VU.zip (VU.slice il (ir - il) adjCsr) (VU.slice il (ir - il) wCsr)
 
--- | \(O(n)\) Returns a vector of @(edgeId, adjacentVertex)@.
+-- | \(O(1)\) Returns the adjacent vertices with \(1\) weights.
+--
+-- @since 1.5.1.0
+{-# INLINE adj1 #-}
+adj1 :: (HasCallStack, VU.Unbox w) => Csr w -> Int -> VU.Vector (Int, Int)
+adj1 Csr {..} i =
+  let il = startCsr VG.! i
+      ir = startCsr VG.! (i + 1)
+   in VU.zip (VU.slice il (ir - il) adjCsr) (VU.replicate (ir - il) 1)
+
+-- | \(O(n)\) Returns a vector of @(csrEdgeIndex, adjacentVertex)@.
 --
 -- @since 1.0.0.0
 {-# INLINE eAdj #-}
@@ -166,3 +178,13 @@ eAdj Csr {..} i =
   let il = startCsr VG.! i
       ir = startCsr VG.! (i + 1)
    in VU.imap ((,) . (+ il)) $ VU.slice il (ir - il) adjCsr
+
+-- | \(O(n)\) Returns a vector of @(csrEdgeIndex, adjacentVertex, edgeWeight)@.
+--
+-- @since 1.4.0.0
+{-# INLINE eAdjW #-}
+eAdjW :: (HasCallStack, VU.Unbox w) => Csr w -> Int -> VU.Vector (Int, Int, w)
+eAdjW Csr {..} i =
+  let il = startCsr VG.! i
+      ir = startCsr VG.! (i + 1)
+   in VU.zip3 (VU.enumFromN il (ir - il)) (VU.slice il (ir - il) adjCsr) (VU.slice il (ir - il) wCsr)
