@@ -1,6 +1,6 @@
 {-# LANGUAGE RecordWildCards #-}
 
--- | Fixed-sized queue. Internally it has an \([l, r)\) pair of valid element bounds.
+-- | Fixed-sized double-ended queue. Internally it has an \([l, r)\) pair of valid element bounds.
 --
 -- ==== __Example__
 -- >>> import AtCoder.Internal.Queue qualified as Q
@@ -111,7 +111,7 @@
 --
 -- >>> Q.freeze que
 -- [0,1]
-
+--
 -- >>> Q.clear que
 -- >>> Q.freeze que
 -- []
@@ -123,6 +123,7 @@ module AtCoder.Internal.Queue
 
     -- * Constructor
     new,
+    newDeque,
 
     -- * Metadata
     capacity,
@@ -176,7 +177,7 @@ import Data.Vector.Unboxed.Mutable qualified as VUM
 import GHC.Stack (HasCallStack)
 import Prelude hiding (length, null)
 
--- | Fixed-sized queue. Internally it has an \([l, r)\) pair of valid element bounds.
+-- | Fixed-sized double-ended queue. Internally it has an \([l, r)\) pair of valid element bounds.
 --
 -- @since 1.0.0.0
 data Queue s a = Queue
@@ -192,6 +193,17 @@ data Queue s a = Queue
 new :: (PrimMonad m, VU.Unbox a) => Int -> m (Queue (PrimState m) a)
 new n = stToPrim $ newST n
 
+-- | \(O(n)\) Creates a `Queue` with capacity \(2n + 1\), where the internal front/back position is
+-- initialized at \(n\).
+--
+-- @since 1.2.4.0
+{-# INLINEABLE newDeque #-}
+newDeque :: (PrimMonad m, VU.Unbox a) => Int -> m (Queue (PrimState m) a)
+newDeque n = stToPrim $ do
+  posQ <- VUM.replicate 2 n
+  vecQ <- VUM.unsafeNew (2 * n + 1)
+  pure Queue {..}
+
 -- | \(O(1)\) Returns the array size.
 --
 -- @since 1.0.0.0
@@ -317,7 +329,7 @@ writeBack :: (HasCallStack, PrimMonad m, VU.Unbox a) => Queue (PrimState m) a ->
 writeBack que i x = stToPrim $ do
   modifyBackM que (pure . const x) i
 
--- | \(O(1)\) Given user function \(f\), returns the \(k\)-th value from the first element.
+-- | \(O(1)\) Given user function \(f\), modifies the \(k\)-th value from the first element with it.
 --
 -- @since 1.2.3.0
 {-# INLINE modifyFront #-}
@@ -325,7 +337,7 @@ modifyFront :: (HasCallStack, PrimMonad m, VU.Unbox a) => Queue (PrimState m) a
 modifyFront que f i = stToPrim $ do
   modifyFrontM que (pure . f) i
 
--- | \(O(1)\) Given user function \(f\), returns the \(k\)-th value from the last element.
+-- | \(O(1)\) Given user function \(f\), modifies the \(k\)-th value from the last element with it.
 --
 -- @since 1.2.3.0
 {-# INLINE modifyBack #-}
@@ -333,7 +345,7 @@ modifyBack :: (HasCallStack, PrimMonad m, VU.Unbox a) => Queue (PrimState m) a -
 modifyBack que f i = stToPrim $ do
   modifyBackM que (pure . f) i
 
--- | \(O(1)\) Given user function \(f\), returns the \(k\)-th value from the first element.
+-- | \(O(1)\) Given user function \(f\), modifies the \(k\)-th value from the first element with it.
 --
 -- @since 1.2.3.0
 {-# INLINE modifyFrontM #-}
@@ -344,7 +356,7 @@ modifyFrontM Queue {..} f i = do
   let !_ = ACIA.runtimeAssert (0 <= i && i < r - l) "AtCoder.Internal.Queue.modifyFrontM: index out of bounds"
   VGM.modifyM vecQ f (l + i)
 
--- | \(O(1)\) Given user function \(f\), returns the \(k\)-th value from the last element.
+-- | \(O(1)\) Given user function \(f\), modifies the \(k\)-th value from the last element with it.
 --
 -- @since 1.2.3.0
 {-# INLINE modifyBackM #-}
