@@ -4,8 +4,8 @@
 -- \((S, \cdot: S \times S \to S, e \in S)\), i.e., the algebraic structure that satisfies the
 -- following properties.
 --
--- - associativity: \((a \cdot b) \cdot c\) = \(a \cdot (b \cdot c)\) for all \(a, b, c \in S\)
--- - existence of the identity element: \(a \cdot e\) = \(e \cdot a\) = \(a\) for all \(a \in S\)
+-- - associativity: \((a \cdot b) \cdot c = a \cdot (b \cdot c)\) for all \(a, b, c \in S\)
+-- - existence of the identity element: \(a \cdot e = e \cdot a = a\) for all \(a \in S\)
 --
 -- Given an array \(S\) of length \(N\), it processes the following queries in \(O(\log N)\) time
 -- (see [Appendix](./appendix.html) for further details).
@@ -14,8 +14,8 @@
 -- - Calculating the product of the elements of an interval
 --
 -- For simplicity, in this document, we assume that the oracles @op@ and @e@ work in constant time.
--- If these oracles work in \(O(T)\) time, each time complexity appear in this document is
--- multipled by \(O(T)\).
+-- If these oracles work in \(O(T)\) time, each time complexity appearing in this document is
+-- multiplied by \(O(T)\).
 --
 -- ==== __Example__
 -- Create a `SegTree` of @'Sum' Int@:
@@ -119,7 +119,7 @@ import Prelude hiding (read)
 --
 -- @since 1.0.0.0
 data SegTree s a = SegTree
-  { -- | THe number of vertices.
+  { -- | The number of vertices.
     --
     -- @since 1.0.0.0
     nSt :: {-# UNPACK #-} !Int,
@@ -171,7 +171,7 @@ build vs = stToPrim $ buildST vs
 write :: (HasCallStack, PrimMonad m, Monoid a, VU.Unbox a) => SegTree (PrimState m) a -> Int -> a -> m ()
 write self p x = stToPrim $ writeST self p x
 
--- | (Extra API) Modifies \(p\)-th value with a function \(f\).
+-- | (Extra API) Given a user function \(f\), modifies \(p\)-th value with it.
 --
 -- ==== Constraints
 -- - \(0 \leq p \lt n\)
@@ -184,7 +184,7 @@ write self p x = stToPrim $ writeST self p x
 modify :: (HasCallStack, PrimMonad m, Monoid a, VU.Unbox a) => SegTree (PrimState m) a -> (a -> a) -> Int -> m ()
 modify self f p = stToPrim $ modifyST self f p
 
--- | (Extra API) Modifies \(p\)-th value with a monadic function \(f\).
+-- | (Extra API) Given a user function \(f\), modifies \(p\)-th value with it.
 --
 -- ==== Constraints
 -- - \(0 \leq p \lt n\)
@@ -298,7 +298,7 @@ minLeft ::
   SegTree (PrimState m) a ->
   -- | \(r\)
   Int ->
-  -- | \(p\): user prediate
+  -- | \(p\): user predicate
   (a -> Bool) ->
   -- | \(l\): \(p\) holds for \([l, r)\)
   m Int
@@ -324,7 +324,7 @@ minLeftM ::
   SegTree (PrimState m) a ->
   -- | \(r\)
   Int ->
-  -- | \(p\): user prediate
+  -- | \(p\): user predicate
   (a -> m Bool) ->
   -- | \(l\): \(p\) holds for \([l, r)\)
   m Int
@@ -386,13 +386,13 @@ maxRight ::
   SegTree (PrimState m) a ->
   -- | \(l\)
   Int ->
-  -- | \(p\): user prediate
+  -- | \(p\): user predicate
   (a -> Bool) ->
   -- | \(r\): \(p\) holds for \([l, r)\)
   m Int
 maxRight seg l0 f = maxRightM seg l0 (pure . f)
 
--- | Moandic variant of `maxRight`.
+-- | Monadic variant of `maxRight`.
 --
 -- ==== Constraints
 -- - if \(f\) is called with the same argument, it returns the same value, i.e., \(f\) has no side effect.
@@ -410,7 +410,7 @@ maxRightM ::
   SegTree (PrimState m) a ->
   -- | \(l\)
   Int ->
-  -- | \(p\): user prediate
+  -- | \(p\): user predicate
   (a -> m Bool) ->
   -- | \(r\): \(p\) holds for \([l, r)\)
   m Int
@@ -449,6 +449,8 @@ maxRightM SegTree {..} l0 f = do
             else inner2 l' sm
       | otherwise = pure $ l - sizeSt
 
+-- TODO: add `minLeft`
+
 -- | \(O(n)\) Yields an immutable copy of the mutable vector.
 --
 -- @since 1.0.0.0
