@@ -4,7 +4,9 @@ import Test.Tasty (testGroup)
 import Test.Tasty.Ingredients.Rerun
 import Tests.Convolution qualified
 import Tests.Dsu qualified
+import Tests.Extra.AhoCorasick qualified
 import Tests.Extra.Bisect qualified
+import Tests.Extra.DsuMonoid qualified
 import Tests.Extra.DynLazySegTree qualified
 import Tests.Extra.DynLazySegTree.Persistent qualified
 import Tests.Extra.DynSegTree qualified
@@ -67,7 +69,9 @@ main =
         testGroup "Dsu" Tests.Dsu.tests,
         testGroup
           "Extra"
-          [ testGroup "Bisect" Tests.Extra.Bisect.tests,
+          [ testGroup "AhoCorasick" Tests.Extra.AhoCorasick.tests,
+            testGroup "Bisect" Tests.Extra.Bisect.tests,
+            testGroup "DsuMonoid" Tests.Extra.DsuMonoid.tests,
             testGroup "DynLazySegTree" Tests.Extra.DynLazySegTree.tests,
             testGroup "DynLazySegTree.Persistent" Tests.Extra.DynLazySegTree.Persistent.tests,
             testGroup "DynSegTree" Tests.Extra.DynSegTree.tests,
