@@ -99,6 +99,13 @@ instance QC.Arbitrary (RollingHash b 998244353) where
     next <- QC.chooseInt (0, 998244353 - 1)
     pure $ RollingHash hash next
 
+-- orphan instance
+instance QC.Arbitrary (RollingHash b 2305843009213693951) where
+  arbitrary = do
+    hash <- QC.chooseInt (0, 2305843009213693951 - 1)
+    next <- QC.chooseInt (0, 2305843009213693951 - 1)
+    pure $ RollingHash hash next
+
 -- orphan instance
 instance QC.Arbitrary (Max Int) where
   arbitrary = Max <$> QC.arbitrary
@@ -253,5 +260,13 @@ tests =
             QCC.monoidLaws,
             QCC.semigroupMonoidLaws
           ]
+      ],
+    testGroup
+      "RollingHash"
+      [ laws @(RollingHash 100 2305843009213693951)
+          [ QCC.semigroupLaws,
+            QCC.monoidLaws,
+            QCC.semigroupMonoidLaws
+          ]
       ]
   ]
