@@ -1,8 +1,9 @@
 module Tests.Internal.MinHeap (tests) where
 
 import AtCoder.Internal.MinHeap qualified as ACIMH
-import Control.Monad
+import Control.Monad (replicateM)
 import Control.Monad.ST (runST)
+import Data.Foldable (for_)
 import Data.List qualified as L
 import Data.Maybe
 import Test.Tasty
@@ -13,11 +14,11 @@ prop_ordered =
   testGroup
     "Ordering"
     [ QC.testProperty "max heap ordering" $ do
-        n <- QC.chooseInt (1, 16)
-        xs <- QC.vectorOf n (QC.chooseInt (-10, 10))
+        n <- QC.chooseInt (1, 64)
+        xs <- QC.vectorOf n (QC.chooseInt (-64, 64))
         let result = runST $ do
               heap <- ACIMH.new n
-              forM_ xs (ACIMH.push heap)
+              for_ xs (ACIMH.push heap)
               replicateM n (fromJust <$> ACIMH.pop heap)
         let expected = L.sort xs
         pure . QC.counterexample (show xs) $ result QC.=== expected
